# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define name            asn1
%define version         0.3.3
%define release         1jpp
%define section         free

# -----------------------------------------------------------------------------

Summary:        Apache ASN.1 Tools
Name:           %{name}
Version:        %{version}
Release:        %{release}
Epoch:		0
Group:          Security/Cryptography
License:        Apache 2.0 License
URL:            http://directory.apache.org/subprojects/asn1/
BuildArch:      noarch
Source0:        %{name}-%{version}-src.tar.gz
# svn export https://svn.apache.org/repos/asf/directory/releases/asn1-0.3.3/

Source1:        pom-maven2jpp-depcat.xsl
Source2:        pom-maven2jpp-newdepmap.xsl
Source3:        pom-maven2jpp-mapdeps.xsl
Source4:        asn1-0.3.3-jpp-depmap.xml
Patch0:		asn1-0.3.3-project_xml.patch
Patch1:		asn1-0.3.3-ber-new-project_xml.patch
Patch2:		asn1-0.3.3-ber-project_xml.patch
Patch3:		asn1-0.3.3-maven_xml.patch
Patch4:		asn1-0.3.3-codec-project_xml.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
Vendor:         JPackage Project
Distribution:   JPackage
BuildRequires:  maven => 0:1.1
BuildRequires:  saxon, saxon-scripts
BuildRequires:	jpackage-utils >= 0:1.5
BuildRequires:	junit
BuildRequires:	maven-plugin-site
BuildRequires:	jakarta-commons-test
BuildRequires:	jakarta-commons-collections
BuildRequires:	jakarta-commons-lang
BuildRequires:	jakarta-commons-primitives
BuildRequires:	mina
BuildRequires:	nlog4j
BuildRequires:	regexp
Requires:	jakarta-commons-collections
Requires:	jakarta-commons-lang
Requires:	jakarta-commons-primitives
Requires:	mina
Requires:	nlog4j
Requires:	regexp


%description
The ASN.1 subproject attempts to isolate the ASN.1 libraries and tools
for encoding ASN.1 in BER/DER/CER/PER encodings. The LDAP and X.500 
aspects of the directory project impose the need for ASN.1 and BER 
codecs.  Kerberos requires DER.  Rather than implement highly
specific and britle code for these needs we decided to separate out
the APIs and implementations used for dealing with ASN.1 codecs for any
ASN.1 defined protocol.

%package javadoc
Group:          Development/Documentation
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%package manual
Group:          Development/Documentation
Summary:        Documents for %{name}

%description manual
Documents for %{name}.

%prep
rm -rf $RPM_BUILD_ROOT
%setup -q -n %{name}-%{version}

%patch0 -b .sav
%patch1 -b .sav
%patch2 -b .sav
%patch3 -b .sav
%patch4 -b .sav

%build
export DEPCAT=$(pwd)/asn1-0.3.3-depcat.new.xml
echo '<?xml version="1.0" standalone="yes"?>' > $DEPCAT
echo '<depset>' >> $DEPCAT
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    /usr/bin/saxon project.xml %{SOURCE1} >> $DEPCAT
    popd
done
echo >> $DEPCAT
echo '</depset>' >> $DEPCAT
/usr/bin/saxon $DEPCAT %{SOURCE2} > asn1-0.3.3-depmap.new.xml
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    /usr/bin/saxon -o project.xml project.xml.orig %{SOURCE3} map=%{SOURCE4}
    popd
done

[ -z "$JAVA_HOME" ] && export JAVA_HOME=%{_jvmdir}/java
mkdir .maven
maven \
	-Dmaven.repo.remote=file:/usr/share/maven/repository \
	-Dmaven.home.local=$(pwd)/.maven \
	multiproject:install multiproject:site

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/%{name}

mv ber-new/target/%{name}-new-ber-%{version}.jar ber-new/target/%{name}-ber-new-%{version}.jar
for j in der ber codec ber-new; do
uvjar=$(echo %{name}-${j}-%{version}.jar | sed s+-%{version}++g)
install -m 644 ${j}/target/%{name}-${j}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}
pushd $RPM_BUILD_ROOT%{_javadir}/%{name}
   ln -fs %{name}-${j}-%{version}.jar ${uvjar}
popd
done

# javadoc and manual
install -d -m 0755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
install -d -m 0755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
for j in der ber codec ber-new; do
    install -d -m 0755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/${j}
    cp -pr ${j}/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/${j}
    rm -rf ${j}/target/docs/apidocs
    install -d -m 0755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/${j}
    cp -pr ${j}/target/docs/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/${j}
done
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink
cp -p LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ "$1" = "0" ]; then
    rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}/LICENSE.txt
%{_javadir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%ghost %{_javadocdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}

%changelog
* Sun Feb 12 2006 Ralph Apel <r.apel at r-apel.de> 0:0.3.3-1jpp
- First JPackage release.
